from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.Windows.Widgets.Feeds.Providers
import win32more.Microsoft.Windows.Widgets.Notifications
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage.Streams
class CustomQueryParametersRequestedArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersRequestedArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersRequestedArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersRequestedArgs) -> hstr: ...
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class CustomQueryParametersUpdateOptions(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersUpdateOptions
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersUpdateOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersUpdateOptions.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersUpdateOptionsFactory, feedProviderDefinitionId: hstr, customQueryParameters: hstr) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersUpdateOptions: ...
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersUpdateOptions) -> hstr: ...
    @winrt_mixinmethod
    def get_CustomQueryParameters(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersUpdateOptions) -> hstr: ...
    CustomQueryParameters = property(get_CustomQueryParameters, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedAnalyticsInfoReportedArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedAnalyticsInfoReportedArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedAnalyticsInfoReportedArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedAnalyticsInfoReportedArgs) -> hstr: ...
    @winrt_mixinmethod
    def get_FeedDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedAnalyticsInfoReportedArgs) -> hstr: ...
    @winrt_mixinmethod
    def get_AnalyticsJson(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedAnalyticsInfoReportedArgs) -> hstr: ...
    AnalyticsJson = property(get_AnalyticsJson, None)
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedDisabledArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedDisabledArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedDisabledArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedDisabledArgs) -> hstr: ...
    @winrt_mixinmethod
    def get_FeedDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedDisabledArgs) -> hstr: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedEnabledArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedEnabledArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedEnabledArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedEnabledArgs) -> hstr: ...
    @winrt_mixinmethod
    def get_FeedDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedEnabledArgs) -> hstr: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedErrorInfoReportedArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedErrorInfoReportedArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedErrorInfoReportedArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedErrorInfoReportedArgs) -> hstr: ...
    @winrt_mixinmethod
    def get_FeedDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedErrorInfoReportedArgs) -> hstr: ...
    @winrt_mixinmethod
    def get_ErrorJson(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedErrorInfoReportedArgs) -> hstr: ...
    ErrorJson = property(get_ErrorJson, None)
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedManager(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedManager
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedManager'
    @winrt_mixinmethod
    def GetEnabledFeedProviders(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedManager) -> ReceiveArray[win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedProviderInfo]: ...
    @winrt_mixinmethod
    def SetCustomQueryParameters(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedManager, options: win32more.Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersUpdateOptions) -> Void: ...
    @winrt_mixinmethod
    def SendMessageToContent(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedManager2, feedProviderDefinitionId: hstr, feedDefinitionId: hstr, message: hstr) -> Void: ...
    @winrt_mixinmethod
    def TryShowAnnouncement(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedManager2, feedProviderDefinitionId: hstr, feedDefinitionId: hstr, announcement: win32more.Microsoft.Windows.Widgets.Notifications.FeedAnnouncement) -> Void: ...
    @winrt_classmethod
    def GetDefault(cls: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedManagerStatics) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedManager: ...
class FeedMessageReceivedArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedMessageReceivedArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedMessageReceivedArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedMessageReceivedArgs) -> hstr: ...
    @winrt_mixinmethod
    def get_FeedDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedMessageReceivedArgs) -> hstr: ...
    @winrt_mixinmethod
    def get_Message(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedMessageReceivedArgs) -> hstr: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
    Message = property(get_Message, None)
class FeedProviderDisabledArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderDisabledArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedProviderDisabledArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderDisabledArgs) -> hstr: ...
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedProviderEnabledArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderEnabledArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedProviderEnabledArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderEnabledArgs) -> hstr: ...
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedProviderInfo(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderInfo
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedProviderInfo'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderInfo) -> hstr: ...
    @winrt_mixinmethod
    def get_EnabledFeedDefinitionIds(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderInfo) -> ReceiveArray[hstr]: ...
    EnabledFeedDefinitionIds = property(get_EnabledFeedDefinitionIds, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class FeedResourceRequest(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceRequest'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest) -> hstr: ...
    @winrt_mixinmethod
    def get_Method(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest) -> hstr: ...
    @winrt_mixinmethod
    def put_Method(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_mixinmethod
    def get_Headers(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest) -> win32more.Windows.Foundation.Collections.StringMap: ...
    @winrt_mixinmethod
    def put_Headers(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest, value: win32more.Windows.Foundation.Collections.StringMap) -> Void: ...
    Content = property(get_Content, put_Content)
    Headers = property(get_Headers, put_Headers)
    Method = property(get_Method, put_Method)
    Uri = property(get_Uri, None)
class FeedResourceRequestedArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceRequestedArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs) -> hstr: ...
    @winrt_mixinmethod
    def get_FeedDefinitionId(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs) -> hstr: ...
    @winrt_mixinmethod
    def get_Request(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceRequest: ...
    @winrt_mixinmethod
    def get_Response(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse: ...
    @winrt_mixinmethod
    def put_Response(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs, value: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse) -> Void: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs) -> win32more.Windows.Foundation.Deferral: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
    Request = property(get_Request, None)
    Response = property(get_Response, put_Response)
class FeedResourceResponse(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponse
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 3:
            super().__init__(move=win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponseFactory, content: win32more.Windows.Storage.Streams.IRandomAccessStreamReference, reasonPhrase: hstr, statusCode: Int32) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponse) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def get_Headers(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponse) -> win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[hstr, hstr]]: ...
    @winrt_mixinmethod
    def put_Headers(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponse, value: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[hstr, hstr]]) -> Void: ...
    @winrt_mixinmethod
    def get_ReasonPhrase(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponse) -> hstr: ...
    @winrt_mixinmethod
    def get_StatusCode(self: win32more.Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponse) -> Int32: ...
    Content = property(get_Content, None)
    Headers = property(get_Headers, put_Headers)
    ReasonPhrase = property(get_ReasonPhrase, None)
    StatusCode = property(get_StatusCode, None)
class ICustomQueryParametersRequestedArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersRequestedArgs'
    _iid_ = Guid('{dc2b0cd8-7936-5346-9371-b21484c7d859}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> hstr: ...
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class ICustomQueryParametersUpdateOptions(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersUpdateOptions'
    _iid_ = Guid('{753f1177-4909-568a-b070-98a3139205ec}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> hstr: ...
    @winrt_commethod(7)
    def get_CustomQueryParameters(self) -> hstr: ...
    CustomQueryParameters = property(get_CustomQueryParameters, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class ICustomQueryParametersUpdateOptionsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.ICustomQueryParametersUpdateOptionsFactory'
    _iid_ = Guid('{34e318cd-3884-53c0-911c-225f32228fae}')
    @winrt_commethod(6)
    def CreateInstance(self, feedProviderDefinitionId: hstr, customQueryParameters: hstr) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersUpdateOptions: ...
class IFeedAnalyticsInfoReportedArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedAnalyticsInfoReportedArgs'
    _iid_ = Guid('{3c0e3d65-ed47-5b8a-b650-39a7edf18942}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> hstr: ...
    @winrt_commethod(7)
    def get_FeedDefinitionId(self) -> hstr: ...
    @winrt_commethod(8)
    def get_AnalyticsJson(self) -> hstr: ...
    AnalyticsJson = property(get_AnalyticsJson, None)
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedAnnouncementInvokedTarget(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedAnnouncementInvokedTarget'
    _iid_ = Guid('{5d44ae2a-072c-4df9-9fe5-34d5d2e9ff63}')
    @winrt_commethod(6)
    def OnAnnouncementInvoked(self, args: win32more.Microsoft.Windows.Widgets.Notifications.FeedAnnouncementInvokedArgs) -> Void: ...
class IFeedDisabledArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedDisabledArgs'
    _iid_ = Guid('{95300612-aca7-53c0-9cf6-d803689132c1}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> hstr: ...
    @winrt_commethod(7)
    def get_FeedDefinitionId(self) -> hstr: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedEnabledArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedEnabledArgs'
    _iid_ = Guid('{eff4b2d7-7347-5969-a77d-cac433f0fdae}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> hstr: ...
    @winrt_commethod(7)
    def get_FeedDefinitionId(self) -> hstr: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedErrorInfoReportedArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedErrorInfoReportedArgs'
    _iid_ = Guid('{62de018c-161e-52d0-9dbe-aec106fb6600}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> hstr: ...
    @winrt_commethod(7)
    def get_FeedDefinitionId(self) -> hstr: ...
    @winrt_commethod(8)
    def get_ErrorJson(self) -> hstr: ...
    ErrorJson = property(get_ErrorJson, None)
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedManager(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedManager'
    _iid_ = Guid('{87df6a84-15aa-45cb-8911-5cafab57f723}')
    @winrt_commethod(6)
    def GetEnabledFeedProviders(self) -> ReceiveArray[win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedProviderInfo]: ...
    @winrt_commethod(7)
    def SetCustomQueryParameters(self, options: win32more.Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersUpdateOptions) -> Void: ...
class IFeedManager2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedManager2'
    _iid_ = Guid('{5838300a-a069-455d-9943-ba078ada00d8}')
    @winrt_commethod(6)
    def SendMessageToContent(self, feedProviderDefinitionId: hstr, feedDefinitionId: hstr, message: hstr) -> Void: ...
    @winrt_commethod(7)
    def TryShowAnnouncement(self, feedProviderDefinitionId: hstr, feedDefinitionId: hstr, announcement: win32more.Microsoft.Windows.Widgets.Notifications.FeedAnnouncement) -> Void: ...
class IFeedManagerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedManagerStatics'
    _iid_ = Guid('{4baf5174-77d6-5e2a-94ea-4f14ccdb1f2c}')
    @winrt_commethod(6)
    def GetDefault(self) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedManager: ...
class IFeedMessageReceivedArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedMessageReceivedArgs'
    _iid_ = Guid('{4ed6ecf9-4c74-5a0b-ae04-bef6dd776f8a}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> hstr: ...
    @winrt_commethod(7)
    def get_FeedDefinitionId(self) -> hstr: ...
    @winrt_commethod(8)
    def get_Message(self) -> hstr: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
    Message = property(get_Message, None)
class IFeedProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedProvider'
    _iid_ = Guid('{7293a12b-0329-458d-ac25-5332be478fde}')
    @winrt_commethod(6)
    def OnFeedProviderEnabled(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedProviderEnabledArgs) -> Void: ...
    @winrt_commethod(7)
    def OnFeedProviderDisabled(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedProviderDisabledArgs) -> Void: ...
    @winrt_commethod(8)
    def OnFeedEnabled(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedEnabledArgs) -> Void: ...
    @winrt_commethod(9)
    def OnFeedDisabled(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedDisabledArgs) -> Void: ...
    @winrt_commethod(10)
    def OnCustomQueryParametersRequested(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.CustomQueryParametersRequestedArgs) -> Void: ...
class IFeedProviderAnalytics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderAnalytics'
    _iid_ = Guid('{f6885791-3085-4bd7-9cb1-4f1354c3a687}')
    @winrt_commethod(6)
    def OnAnalyticsInfoReported(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedAnalyticsInfoReportedArgs) -> Void: ...
class IFeedProviderDisabledArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderDisabledArgs'
    _iid_ = Guid('{19b65aec-e01d-5e8c-ab5f-324212e7cd30}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> hstr: ...
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedProviderEnabledArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderEnabledArgs'
    _iid_ = Guid('{821fc9af-0de6-5a9b-9ae6-e179117b40e4}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> hstr: ...
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedProviderErrors(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderErrors'
    _iid_ = Guid('{6611e00a-d86c-49a3-9381-b7da67ee62dc}')
    @winrt_commethod(6)
    def OnErrorInfoReported(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedErrorInfoReportedArgs) -> Void: ...
class IFeedProviderInfo(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderInfo'
    _iid_ = Guid('{73c37049-3c03-5896-8532-f9dfdaeb723f}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> hstr: ...
    @winrt_commethod(7)
    def get_EnabledFeedDefinitionIds(self) -> ReceiveArray[hstr]: ...
    EnabledFeedDefinitionIds = property(get_EnabledFeedDefinitionIds, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedProviderMessage(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedProviderMessage'
    _iid_ = Guid('{60c2442a-4c9d-4880-ba26-caca9e567dd4}')
    @winrt_commethod(6)
    def OnMessageReceived(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedMessageReceivedArgs) -> Void: ...
class IFeedResourceProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceProvider'
    _iid_ = Guid('{e1b6266d-88a0-416c-9440-e341cb047cd3}')
    @winrt_commethod(6)
    def OnResourceRequested(self, args: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceRequestedArgs) -> Void: ...
class IFeedResourceRequest(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequest'
    _iid_ = Guid('{e62e479c-e21f-5863-b4c9-df1be2227981}')
    @winrt_commethod(6)
    def get_Uri(self) -> hstr: ...
    @winrt_commethod(7)
    def get_Method(self) -> hstr: ...
    @winrt_commethod(8)
    def put_Method(self, value: hstr) -> Void: ...
    @winrt_commethod(9)
    def get_Content(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_commethod(10)
    def put_Content(self, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_commethod(11)
    def get_Headers(self) -> win32more.Windows.Foundation.Collections.StringMap: ...
    @winrt_commethod(12)
    def put_Headers(self, value: win32more.Windows.Foundation.Collections.StringMap) -> Void: ...
    Content = property(get_Content, put_Content)
    Headers = property(get_Headers, put_Headers)
    Method = property(get_Method, put_Method)
    Uri = property(get_Uri, None)
class IFeedResourceRequestedArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceRequestedArgs'
    _iid_ = Guid('{360eb709-0bc9-52c1-9c70-3c7d413173d8}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> hstr: ...
    @winrt_commethod(7)
    def get_FeedDefinitionId(self) -> hstr: ...
    @winrt_commethod(8)
    def get_Request(self) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceRequest: ...
    @winrt_commethod(9)
    def get_Response(self) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse: ...
    @winrt_commethod(10)
    def put_Response(self, value: win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse) -> Void: ...
    @winrt_commethod(11)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
    Request = property(get_Request, None)
    Response = property(get_Response, put_Response)
class IFeedResourceResponse(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponse'
    _iid_ = Guid('{f831824e-7aef-53fc-b7ee-32ade675a3ad}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_commethod(7)
    def get_Headers(self) -> win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[hstr, hstr]]: ...
    @winrt_commethod(8)
    def put_Headers(self, value: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[hstr, hstr]]) -> Void: ...
    @winrt_commethod(9)
    def get_ReasonPhrase(self) -> hstr: ...
    @winrt_commethod(10)
    def get_StatusCode(self) -> Int32: ...
    Content = property(get_Content, None)
    Headers = property(get_Headers, put_Headers)
    ReasonPhrase = property(get_ReasonPhrase, None)
    StatusCode = property(get_StatusCode, None)
class IFeedResourceResponseFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Feeds.Providers.IFeedResourceResponseFactory'
    _iid_ = Guid('{db01690d-2547-5d7a-b625-d1629f443c5c}')
    @winrt_commethod(6)
    def CreateInstance(self, content: win32more.Windows.Storage.Streams.IRandomAccessStreamReference, reasonPhrase: hstr, statusCode: Int32) -> win32more.Microsoft.Windows.Widgets.Feeds.Providers.FeedResourceResponse: ...


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.UI.Composition
import win32more.Microsoft.UI.Xaml
import win32more.Microsoft.UI.Xaml.Media
import win32more.Microsoft.UI.Xaml.Shapes
class Ellipse(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Shapes.Shape
    default_interface: win32more.Microsoft.UI.Xaml.Shapes.IEllipse
    _classid_ = 'Microsoft.UI.Xaml.Shapes.Ellipse'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Shapes.Ellipse.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Shapes.Ellipse: ...
class IEllipse(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IEllipse'
    _iid_ = Guid('{805c39aa-fa8a-5e0b-9847-4ab81b42a3df}')
class ILine(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.ILine'
    _iid_ = Guid('{507b3858-af7e-559b-a87e-4cc6a5d8ba96}')
    @winrt_commethod(6)
    def get_X1(self) -> Double: ...
    @winrt_commethod(7)
    def put_X1(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_Y1(self) -> Double: ...
    @winrt_commethod(9)
    def put_Y1(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_X2(self) -> Double: ...
    @winrt_commethod(11)
    def put_X2(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_Y2(self) -> Double: ...
    @winrt_commethod(13)
    def put_Y2(self, value: Double) -> Void: ...
    X1 = property(get_X1, put_X1)
    X2 = property(get_X2, put_X2)
    Y1 = property(get_Y1, put_Y1)
    Y2 = property(get_Y2, put_Y2)
class ILineStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.ILineStatics'
    _iid_ = Guid('{a425bf93-f1f3-5dcb-997e-b6a26f7ae8c0}')
    @winrt_commethod(6)
    def get_X1Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_Y1Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_X2Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_Y2Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    X1Property = property(get_X1Property, None)
    X2Property = property(get_X2Property, None)
    Y1Property = property(get_Y1Property, None)
    Y2Property = property(get_Y2Property, None)
class IPath(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IPath'
    _iid_ = Guid('{757d1cd8-0ec0-55c5-b400-66657e493e78}')
    @winrt_commethod(6)
    def get_Data(self) -> win32more.Microsoft.UI.Xaml.Media.Geometry: ...
    @winrt_commethod(7)
    def put_Data(self, value: win32more.Microsoft.UI.Xaml.Media.Geometry) -> Void: ...
    Data = property(get_Data, put_Data)
class IPathFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IPathFactory'
    _iid_ = Guid('{5e82e4c9-7502-5b1f-b940-c3346a71362a}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Shapes.Path: ...
class IPathStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IPathStatics'
    _iid_ = Guid('{2146d36f-721c-5b54-af7d-60f3adc4fbca}')
    @winrt_commethod(6)
    def get_DataProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DataProperty = property(get_DataProperty, None)
class IPolygon(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IPolygon'
    _iid_ = Guid('{fa126347-d1d4-54dd-b1a4-c35019397944}')
    @winrt_commethod(6)
    def get_FillRule(self) -> win32more.Microsoft.UI.Xaml.Media.FillRule: ...
    @winrt_commethod(7)
    def put_FillRule(self, value: win32more.Microsoft.UI.Xaml.Media.FillRule) -> Void: ...
    @winrt_commethod(8)
    def get_Points(self) -> win32more.Microsoft.UI.Xaml.Media.PointCollection: ...
    @winrt_commethod(9)
    def put_Points(self, value: win32more.Microsoft.UI.Xaml.Media.PointCollection) -> Void: ...
    FillRule = property(get_FillRule, put_FillRule)
    Points = property(get_Points, put_Points)
class IPolygonStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IPolygonStatics'
    _iid_ = Guid('{85ddbada-9e37-5971-a9aa-dce31f9cf67a}')
    @winrt_commethod(6)
    def get_FillRuleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PointsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FillRuleProperty = property(get_FillRuleProperty, None)
    PointsProperty = property(get_PointsProperty, None)
class IPolyline(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IPolyline'
    _iid_ = Guid('{c7f0bec6-184c-5d96-8102-04dd211e100c}')
    @winrt_commethod(6)
    def get_FillRule(self) -> win32more.Microsoft.UI.Xaml.Media.FillRule: ...
    @winrt_commethod(7)
    def put_FillRule(self, value: win32more.Microsoft.UI.Xaml.Media.FillRule) -> Void: ...
    @winrt_commethod(8)
    def get_Points(self) -> win32more.Microsoft.UI.Xaml.Media.PointCollection: ...
    @winrt_commethod(9)
    def put_Points(self, value: win32more.Microsoft.UI.Xaml.Media.PointCollection) -> Void: ...
    FillRule = property(get_FillRule, put_FillRule)
    Points = property(get_Points, put_Points)
class IPolylineStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IPolylineStatics'
    _iid_ = Guid('{48840fe7-d735-5080-9c6d-2862665cdda0}')
    @winrt_commethod(6)
    def get_FillRuleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PointsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FillRuleProperty = property(get_FillRuleProperty, None)
    PointsProperty = property(get_PointsProperty, None)
class IRectangle(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IRectangle'
    _iid_ = Guid('{bf7d30b9-152c-556e-9f10-d0b7eba4e52f}')
    @winrt_commethod(6)
    def get_RadiusX(self) -> Double: ...
    @winrt_commethod(7)
    def put_RadiusX(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_RadiusY(self) -> Double: ...
    @winrt_commethod(9)
    def put_RadiusY(self, value: Double) -> Void: ...
    RadiusX = property(get_RadiusX, put_RadiusX)
    RadiusY = property(get_RadiusY, put_RadiusY)
class IRectangleStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IRectangleStatics'
    _iid_ = Guid('{3cc3cc79-c332-5ad0-8743-1f1b1e670a86}')
    @winrt_commethod(6)
    def get_RadiusXProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_RadiusYProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    RadiusXProperty = property(get_RadiusXProperty, None)
    RadiusYProperty = property(get_RadiusYProperty, None)
class IShape(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IShape'
    _iid_ = Guid('{9941aad3-6af2-5ba2-9085-8506d5f2485e}')
    @winrt_commethod(6)
    def get_Fill(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(7)
    def put_Fill(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(8)
    def get_Stroke(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(9)
    def put_Stroke(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(10)
    def get_StrokeMiterLimit(self) -> Double: ...
    @winrt_commethod(11)
    def put_StrokeMiterLimit(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_StrokeThickness(self) -> Double: ...
    @winrt_commethod(13)
    def put_StrokeThickness(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_StrokeStartLineCap(self) -> win32more.Microsoft.UI.Xaml.Media.PenLineCap: ...
    @winrt_commethod(15)
    def put_StrokeStartLineCap(self, value: win32more.Microsoft.UI.Xaml.Media.PenLineCap) -> Void: ...
    @winrt_commethod(16)
    def get_StrokeEndLineCap(self) -> win32more.Microsoft.UI.Xaml.Media.PenLineCap: ...
    @winrt_commethod(17)
    def put_StrokeEndLineCap(self, value: win32more.Microsoft.UI.Xaml.Media.PenLineCap) -> Void: ...
    @winrt_commethod(18)
    def get_StrokeLineJoin(self) -> win32more.Microsoft.UI.Xaml.Media.PenLineJoin: ...
    @winrt_commethod(19)
    def put_StrokeLineJoin(self, value: win32more.Microsoft.UI.Xaml.Media.PenLineJoin) -> Void: ...
    @winrt_commethod(20)
    def get_StrokeDashOffset(self) -> Double: ...
    @winrt_commethod(21)
    def put_StrokeDashOffset(self, value: Double) -> Void: ...
    @winrt_commethod(22)
    def get_StrokeDashCap(self) -> win32more.Microsoft.UI.Xaml.Media.PenLineCap: ...
    @winrt_commethod(23)
    def put_StrokeDashCap(self, value: win32more.Microsoft.UI.Xaml.Media.PenLineCap) -> Void: ...
    @winrt_commethod(24)
    def get_StrokeDashArray(self) -> win32more.Microsoft.UI.Xaml.Media.DoubleCollection: ...
    @winrt_commethod(25)
    def put_StrokeDashArray(self, value: win32more.Microsoft.UI.Xaml.Media.DoubleCollection) -> Void: ...
    @winrt_commethod(26)
    def get_Stretch(self) -> win32more.Microsoft.UI.Xaml.Media.Stretch: ...
    @winrt_commethod(27)
    def put_Stretch(self, value: win32more.Microsoft.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_commethod(28)
    def get_GeometryTransform(self) -> win32more.Microsoft.UI.Xaml.Media.Transform: ...
    @winrt_commethod(29)
    def GetAlphaMask(self) -> win32more.Microsoft.UI.Composition.CompositionBrush: ...
    Fill = property(get_Fill, put_Fill)
    GeometryTransform = property(get_GeometryTransform, None)
    Stretch = property(get_Stretch, put_Stretch)
    Stroke = property(get_Stroke, put_Stroke)
    StrokeDashArray = property(get_StrokeDashArray, put_StrokeDashArray)
    StrokeDashCap = property(get_StrokeDashCap, put_StrokeDashCap)
    StrokeDashOffset = property(get_StrokeDashOffset, put_StrokeDashOffset)
    StrokeEndLineCap = property(get_StrokeEndLineCap, put_StrokeEndLineCap)
    StrokeLineJoin = property(get_StrokeLineJoin, put_StrokeLineJoin)
    StrokeMiterLimit = property(get_StrokeMiterLimit, put_StrokeMiterLimit)
    StrokeStartLineCap = property(get_StrokeStartLineCap, put_StrokeStartLineCap)
    StrokeThickness = property(get_StrokeThickness, put_StrokeThickness)
class IShapeFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IShapeFactory'
    _iid_ = Guid('{4fecafaf-8265-5252-ba5c-f43639f974a5}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Shapes.Shape: ...
class IShapeStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IShapeStatics'
    _iid_ = Guid('{ea407c43-8a09-587a-958a-4dd17d217ce1}')
    @winrt_commethod(6)
    def get_FillProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_StrokeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_StrokeMiterLimitProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_StrokeThicknessProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_StrokeStartLineCapProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_StrokeEndLineCapProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_StrokeLineJoinProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_StrokeDashOffsetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_StrokeDashCapProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_StrokeDashArrayProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_StretchProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FillProperty = property(get_FillProperty, None)
    StretchProperty = property(get_StretchProperty, None)
    StrokeDashArrayProperty = property(get_StrokeDashArrayProperty, None)
    StrokeDashCapProperty = property(get_StrokeDashCapProperty, None)
    StrokeDashOffsetProperty = property(get_StrokeDashOffsetProperty, None)
    StrokeEndLineCapProperty = property(get_StrokeEndLineCapProperty, None)
    StrokeLineJoinProperty = property(get_StrokeLineJoinProperty, None)
    StrokeMiterLimitProperty = property(get_StrokeMiterLimitProperty, None)
    StrokeProperty = property(get_StrokeProperty, None)
    StrokeStartLineCapProperty = property(get_StrokeStartLineCapProperty, None)
    StrokeThicknessProperty = property(get_StrokeThicknessProperty, None)
class _Line_Meta_(ComPtr.__class__):
    pass
class Line(ComPtr, metaclass=_Line_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Shapes.Shape
    default_interface: win32more.Microsoft.UI.Xaml.Shapes.ILine
    _classid_ = 'Microsoft.UI.Xaml.Shapes.Line'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Shapes.Line.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Shapes.Line: ...
    @winrt_mixinmethod
    def get_X1(self: win32more.Microsoft.UI.Xaml.Shapes.ILine) -> Double: ...
    @winrt_mixinmethod
    def put_X1(self: win32more.Microsoft.UI.Xaml.Shapes.ILine, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Y1(self: win32more.Microsoft.UI.Xaml.Shapes.ILine) -> Double: ...
    @winrt_mixinmethod
    def put_Y1(self: win32more.Microsoft.UI.Xaml.Shapes.ILine, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_X2(self: win32more.Microsoft.UI.Xaml.Shapes.ILine) -> Double: ...
    @winrt_mixinmethod
    def put_X2(self: win32more.Microsoft.UI.Xaml.Shapes.ILine, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Y2(self: win32more.Microsoft.UI.Xaml.Shapes.ILine) -> Double: ...
    @winrt_mixinmethod
    def put_Y2(self: win32more.Microsoft.UI.Xaml.Shapes.ILine, value: Double) -> Void: ...
    @winrt_classmethod
    def get_X1Property(cls: win32more.Microsoft.UI.Xaml.Shapes.ILineStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_Y1Property(cls: win32more.Microsoft.UI.Xaml.Shapes.ILineStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_X2Property(cls: win32more.Microsoft.UI.Xaml.Shapes.ILineStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_Y2Property(cls: win32more.Microsoft.UI.Xaml.Shapes.ILineStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    X1 = property(get_X1, put_X1)
    X2 = property(get_X2, put_X2)
    Y1 = property(get_Y1, put_Y1)
    Y2 = property(get_Y2, put_Y2)
    _Line_Meta_.X1Property = property(get_X1Property, None)
    _Line_Meta_.X2Property = property(get_X2Property, None)
    _Line_Meta_.Y1Property = property(get_Y1Property, None)
    _Line_Meta_.Y2Property = property(get_Y2Property, None)
class _Path_Meta_(ComPtr.__class__):
    pass
class Path(ComPtr, metaclass=_Path_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Shapes.Shape
    default_interface: win32more.Microsoft.UI.Xaml.Shapes.IPath
    _classid_ = 'Microsoft.UI.Xaml.Shapes.Path'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Shapes.Path.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Shapes.IPathFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Shapes.Path: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Microsoft.UI.Xaml.Shapes.IPath) -> win32more.Microsoft.UI.Xaml.Media.Geometry: ...
    @winrt_mixinmethod
    def put_Data(self: win32more.Microsoft.UI.Xaml.Shapes.IPath, value: win32more.Microsoft.UI.Xaml.Media.Geometry) -> Void: ...
    @winrt_classmethod
    def get_DataProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IPathStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Data = property(get_Data, put_Data)
    _Path_Meta_.DataProperty = property(get_DataProperty, None)
class _Polygon_Meta_(ComPtr.__class__):
    pass
class Polygon(ComPtr, metaclass=_Polygon_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Shapes.Shape
    default_interface: win32more.Microsoft.UI.Xaml.Shapes.IPolygon
    _classid_ = 'Microsoft.UI.Xaml.Shapes.Polygon'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Shapes.Polygon.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Shapes.Polygon: ...
    @winrt_mixinmethod
    def get_FillRule(self: win32more.Microsoft.UI.Xaml.Shapes.IPolygon) -> win32more.Microsoft.UI.Xaml.Media.FillRule: ...
    @winrt_mixinmethod
    def put_FillRule(self: win32more.Microsoft.UI.Xaml.Shapes.IPolygon, value: win32more.Microsoft.UI.Xaml.Media.FillRule) -> Void: ...
    @winrt_mixinmethod
    def get_Points(self: win32more.Microsoft.UI.Xaml.Shapes.IPolygon) -> win32more.Microsoft.UI.Xaml.Media.PointCollection: ...
    @winrt_mixinmethod
    def put_Points(self: win32more.Microsoft.UI.Xaml.Shapes.IPolygon, value: win32more.Microsoft.UI.Xaml.Media.PointCollection) -> Void: ...
    @winrt_classmethod
    def get_FillRuleProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IPolygonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PointsProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IPolygonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FillRule = property(get_FillRule, put_FillRule)
    Points = property(get_Points, put_Points)
    _Polygon_Meta_.FillRuleProperty = property(get_FillRuleProperty, None)
    _Polygon_Meta_.PointsProperty = property(get_PointsProperty, None)
class _Polyline_Meta_(ComPtr.__class__):
    pass
class Polyline(ComPtr, metaclass=_Polyline_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Shapes.Shape
    default_interface: win32more.Microsoft.UI.Xaml.Shapes.IPolyline
    _classid_ = 'Microsoft.UI.Xaml.Shapes.Polyline'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Shapes.Polyline.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Shapes.Polyline: ...
    @winrt_mixinmethod
    def get_FillRule(self: win32more.Microsoft.UI.Xaml.Shapes.IPolyline) -> win32more.Microsoft.UI.Xaml.Media.FillRule: ...
    @winrt_mixinmethod
    def put_FillRule(self: win32more.Microsoft.UI.Xaml.Shapes.IPolyline, value: win32more.Microsoft.UI.Xaml.Media.FillRule) -> Void: ...
    @winrt_mixinmethod
    def get_Points(self: win32more.Microsoft.UI.Xaml.Shapes.IPolyline) -> win32more.Microsoft.UI.Xaml.Media.PointCollection: ...
    @winrt_mixinmethod
    def put_Points(self: win32more.Microsoft.UI.Xaml.Shapes.IPolyline, value: win32more.Microsoft.UI.Xaml.Media.PointCollection) -> Void: ...
    @winrt_classmethod
    def get_FillRuleProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IPolylineStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PointsProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IPolylineStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FillRule = property(get_FillRule, put_FillRule)
    Points = property(get_Points, put_Points)
    _Polyline_Meta_.FillRuleProperty = property(get_FillRuleProperty, None)
    _Polyline_Meta_.PointsProperty = property(get_PointsProperty, None)
class _Rectangle_Meta_(ComPtr.__class__):
    pass
class Rectangle(ComPtr, metaclass=_Rectangle_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Shapes.Shape
    default_interface: win32more.Microsoft.UI.Xaml.Shapes.IRectangle
    _classid_ = 'Microsoft.UI.Xaml.Shapes.Rectangle'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Shapes.Rectangle.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Shapes.Rectangle: ...
    @winrt_mixinmethod
    def get_RadiusX(self: win32more.Microsoft.UI.Xaml.Shapes.IRectangle) -> Double: ...
    @winrt_mixinmethod
    def put_RadiusX(self: win32more.Microsoft.UI.Xaml.Shapes.IRectangle, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_RadiusY(self: win32more.Microsoft.UI.Xaml.Shapes.IRectangle) -> Double: ...
    @winrt_mixinmethod
    def put_RadiusY(self: win32more.Microsoft.UI.Xaml.Shapes.IRectangle, value: Double) -> Void: ...
    @winrt_classmethod
    def get_RadiusXProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IRectangleStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RadiusYProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IRectangleStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    RadiusX = property(get_RadiusX, put_RadiusX)
    RadiusY = property(get_RadiusY, put_RadiusY)
    _Rectangle_Meta_.RadiusXProperty = property(get_RadiusXProperty, None)
    _Rectangle_Meta_.RadiusYProperty = property(get_RadiusYProperty, None)
class _Shape_Meta_(ComPtr.__class__):
    pass
class Shape(ComPtr, metaclass=_Shape_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Shapes.IShape
    _classid_ = 'Microsoft.UI.Xaml.Shapes.Shape'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Shapes.Shape.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Shapes.Shape: ...
    @winrt_mixinmethod
    def get_Fill(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Fill(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_Stroke(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Stroke(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeMiterLimit(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> Double: ...
    @winrt_mixinmethod
    def put_StrokeMiterLimit(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeThickness(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> Double: ...
    @winrt_mixinmethod
    def put_StrokeThickness(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeStartLineCap(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.PenLineCap: ...
    @winrt_mixinmethod
    def put_StrokeStartLineCap(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.PenLineCap) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeEndLineCap(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.PenLineCap: ...
    @winrt_mixinmethod
    def put_StrokeEndLineCap(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.PenLineCap) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeLineJoin(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.PenLineJoin: ...
    @winrt_mixinmethod
    def put_StrokeLineJoin(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.PenLineJoin) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeDashOffset(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> Double: ...
    @winrt_mixinmethod
    def put_StrokeDashOffset(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeDashCap(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.PenLineCap: ...
    @winrt_mixinmethod
    def put_StrokeDashCap(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.PenLineCap) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeDashArray(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.DoubleCollection: ...
    @winrt_mixinmethod
    def put_StrokeDashArray(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.DoubleCollection) -> Void: ...
    @winrt_mixinmethod
    def get_Stretch(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.Stretch: ...
    @winrt_mixinmethod
    def put_Stretch(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_mixinmethod
    def get_GeometryTransform(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.Transform: ...
    @winrt_mixinmethod
    def GetAlphaMask(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Composition.CompositionBrush: ...
    @winrt_classmethod
    def get_FillProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeMiterLimitProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeThicknessProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeStartLineCapProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeEndLineCapProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeLineJoinProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeDashOffsetProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeDashCapProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeDashArrayProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StretchProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Fill = property(get_Fill, put_Fill)
    GeometryTransform = property(get_GeometryTransform, None)
    Stretch = property(get_Stretch, put_Stretch)
    Stroke = property(get_Stroke, put_Stroke)
    StrokeDashArray = property(get_StrokeDashArray, put_StrokeDashArray)
    StrokeDashCap = property(get_StrokeDashCap, put_StrokeDashCap)
    StrokeDashOffset = property(get_StrokeDashOffset, put_StrokeDashOffset)
    StrokeEndLineCap = property(get_StrokeEndLineCap, put_StrokeEndLineCap)
    StrokeLineJoin = property(get_StrokeLineJoin, put_StrokeLineJoin)
    StrokeMiterLimit = property(get_StrokeMiterLimit, put_StrokeMiterLimit)
    StrokeStartLineCap = property(get_StrokeStartLineCap, put_StrokeStartLineCap)
    StrokeThickness = property(get_StrokeThickness, put_StrokeThickness)
    _Shape_Meta_.FillProperty = property(get_FillProperty, None)
    _Shape_Meta_.StretchProperty = property(get_StretchProperty, None)
    _Shape_Meta_.StrokeDashArrayProperty = property(get_StrokeDashArrayProperty, None)
    _Shape_Meta_.StrokeDashCapProperty = property(get_StrokeDashCapProperty, None)
    _Shape_Meta_.StrokeDashOffsetProperty = property(get_StrokeDashOffsetProperty, None)
    _Shape_Meta_.StrokeEndLineCapProperty = property(get_StrokeEndLineCapProperty, None)
    _Shape_Meta_.StrokeLineJoinProperty = property(get_StrokeLineJoinProperty, None)
    _Shape_Meta_.StrokeMiterLimitProperty = property(get_StrokeMiterLimitProperty, None)
    _Shape_Meta_.StrokeProperty = property(get_StrokeProperty, None)
    _Shape_Meta_.StrokeStartLineCapProperty = property(get_StrokeStartLineCapProperty, None)
    _Shape_Meta_.StrokeThicknessProperty = property(get_StrokeThicknessProperty, None)


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.UI.Xaml.Markup
import win32more.Microsoft.UI.Xaml.XamlTypeInfo
import win32more.Windows.UI.Xaml.Interop
class IXamlControlsXamlMetaDataProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.XamlTypeInfo.IXamlControlsXamlMetaDataProvider'
    _iid_ = Guid('{17fa3f58-3472-5aa2-a0f8-1ab8a519573d}')
class IXamlControlsXamlMetaDataProviderStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.XamlTypeInfo.IXamlControlsXamlMetaDataProviderStatics'
    _iid_ = Guid('{2d7eb3fd-ecdb-5084-b7e0-12f9598381ef}')
    @winrt_commethod(6)
    def Initialize(self) -> Void: ...
class XamlControlsXamlMetaDataProvider(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Markup.IXamlMetadataProvider
    _classid_ = 'Microsoft.UI.Xaml.XamlTypeInfo.XamlControlsXamlMetaDataProvider'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.XamlTypeInfo.XamlControlsXamlMetaDataProvider.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.XamlTypeInfo.XamlControlsXamlMetaDataProvider: ...
    @winrt_mixinmethod
    def GetXamlType(self: win32more.Microsoft.UI.Xaml.Markup.IXamlMetadataProvider, type: win32more.Windows.UI.Xaml.Interop.TypeName) -> win32more.Microsoft.UI.Xaml.Markup.IXamlType: ...
    @winrt_mixinmethod
    def GetXamlTypeByFullName(self: win32more.Microsoft.UI.Xaml.Markup.IXamlMetadataProvider, fullName: hstr) -> win32more.Microsoft.UI.Xaml.Markup.IXamlType: ...
    @winrt_mixinmethod
    def GetXmlnsDefinitions(self: win32more.Microsoft.UI.Xaml.Markup.IXamlMetadataProvider) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Markup.XmlnsDefinition]: ...
    @winrt_classmethod
    def Initialize(cls: win32more.Microsoft.UI.Xaml.XamlTypeInfo.IXamlControlsXamlMetaDataProviderStatics) -> Void: ...


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.UI.Content
import win32more.Microsoft.UI.Input
import win32more.Microsoft.UI.Input.DragDrop
import win32more.Windows.ApplicationModel.DataTransfer
import win32more.Windows.Foundation
import win32more.Windows.Graphics.Imaging
class DragDropManager(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.UI.Input.DragDrop.IDragDropManager
    _classid_ = 'Microsoft.UI.Input.DragDrop.DragDropManager'
    @winrt_mixinmethod
    def add_TargetRequested(self: win32more.Microsoft.UI.Input.DragDrop.IDragDropManager, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Input.DragDrop.DragDropManager, win32more.Microsoft.UI.Input.DragDrop.DropOperationTargetRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def put_AreConcurrentOperationsEnabled(self: win32more.Microsoft.UI.Input.DragDrop.IDragDropManager, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def remove_TargetRequested(self: win32more.Microsoft.UI.Input.DragDrop.IDragDropManager, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_AreConcurrentOperationsEnabled(self: win32more.Microsoft.UI.Input.DragDrop.IDragDropManager) -> Boolean: ...
    @winrt_classmethod
    def GetForIsland(cls: win32more.Microsoft.UI.Input.DragDrop.IDragDropManagerStatics, content: win32more.Microsoft.UI.Content.ContentIsland) -> win32more.Microsoft.UI.Input.DragDrop.DragDropManager: ...
    AreConcurrentOperationsEnabled = property(get_AreConcurrentOperationsEnabled, put_AreConcurrentOperationsEnabled)
    TargetRequested = event(add_TargetRequested, remove_TargetRequested)
class DragDropModifiers(Enum, UInt32):
    None_ = 0
    Shift = 1
    Control = 2
    Alt = 4
    LeftButton = 8
    MiddleButton = 16
    RightButton = 32
class DragInfo(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Input.DragDrop.IDragInfo
    _classid_ = 'Microsoft.UI.Input.DragDrop.DragInfo'
    @winrt_mixinmethod
    def get_Position(self: win32more.Microsoft.UI.Input.DragDrop.IDragInfo) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Microsoft.UI.Input.DragDrop.IDragInfo) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageView: ...
    @winrt_mixinmethod
    def get_Modifiers(self: win32more.Microsoft.UI.Input.DragDrop.IDragInfo) -> win32more.Microsoft.UI.Input.DragDrop.DragDropModifiers: ...
    @winrt_mixinmethod
    def get_AllowedOperations(self: win32more.Microsoft.UI.Input.DragDrop.IDragInfo) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation: ...
    AllowedOperations = property(get_AllowedOperations, None)
    Data = property(get_Data, None)
    Modifiers = property(get_Modifiers, None)
    Position = property(get_Position, None)
class DragOperation(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.UI.Input.DragDrop.IDragOperation
    _classid_ = 'Microsoft.UI.Input.DragDrop.DragOperation'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Input.DragDrop.DragOperation.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Input.DragDrop.DragOperation: ...
    @winrt_mixinmethod
    def SetDragUIContentFromSoftwareBitmap(self: win32more.Microsoft.UI.Input.DragDrop.IDragOperation, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> Void: ...
    @winrt_mixinmethod
    def put_AllowedOperations(self: win32more.Microsoft.UI.Input.DragDrop.IDragOperation, value: win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation) -> Void: ...
    @winrt_mixinmethod
    def get_AllowedOperations(self: win32more.Microsoft.UI.Input.DragDrop.IDragOperation) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation: ...
    @winrt_mixinmethod
    def get_DragUIContentMode(self: win32more.Microsoft.UI.Input.DragDrop.IDragOperation) -> win32more.Microsoft.UI.Input.DragDrop.DragUIContentMode: ...
    @winrt_mixinmethod
    def put_DragUIContentMode(self: win32more.Microsoft.UI.Input.DragDrop.IDragOperation, value: win32more.Microsoft.UI.Input.DragDrop.DragUIContentMode) -> Void: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Microsoft.UI.Input.DragDrop.IDragOperation) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackage: ...
    @winrt_mixinmethod
    def SetDragUIContentFromSoftwareBitmap2(self: win32more.Microsoft.UI.Input.DragDrop.IDragOperation, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap, anchorPoint: win32more.Windows.Foundation.Point) -> Void: ...
    @winrt_mixinmethod
    def StartAsync(self: win32more.Microsoft.UI.Input.DragDrop.IDragOperation, initialTarget: win32more.Microsoft.UI.Input.DragDrop.DragDropManager, initialPointerPoint: win32more.Microsoft.UI.Input.PointerPoint) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation]: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    AllowedOperations = property(get_AllowedOperations, put_AllowedOperations)
    Data = property(get_Data, None)
    DragUIContentMode = property(get_DragUIContentMode, put_DragUIContentMode)
class DragUIContentMode(Enum, Int32):
    Auto = 0
    Deferred = 1
class DragUIOverride(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Input.DragDrop.IDragUIOverride
    _classid_ = 'Microsoft.UI.Input.DragDrop.DragUIOverride'
    @winrt_mixinmethod
    def put_IsGlyphVisible(self: win32more.Microsoft.UI.Input.DragDrop.IDragUIOverride, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def put_Caption(self: win32more.Microsoft.UI.Input.DragDrop.IDragUIOverride, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_IsCaptionVisible(self: win32more.Microsoft.UI.Input.DragDrop.IDragUIOverride) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCaptionVisible(self: win32more.Microsoft.UI.Input.DragDrop.IDragUIOverride, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsContentVisible(self: win32more.Microsoft.UI.Input.DragDrop.IDragUIOverride) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsContentVisible(self: win32more.Microsoft.UI.Input.DragDrop.IDragUIOverride, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsGlyphVisible(self: win32more.Microsoft.UI.Input.DragDrop.IDragUIOverride) -> Boolean: ...
    @winrt_mixinmethod
    def get_Caption(self: win32more.Microsoft.UI.Input.DragDrop.IDragUIOverride) -> hstr: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Microsoft.UI.Input.DragDrop.IDragUIOverride) -> Void: ...
    @winrt_mixinmethod
    def SetContentFromSoftwareBitmap(self: win32more.Microsoft.UI.Input.DragDrop.IDragUIOverride, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> Void: ...
    @winrt_mixinmethod
    def SetContentFromSoftwareBitmap2(self: win32more.Microsoft.UI.Input.DragDrop.IDragUIOverride, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap, anchorPoint: win32more.Windows.Foundation.Point) -> Void: ...
    Caption = property(get_Caption, put_Caption)
    IsCaptionVisible = property(get_IsCaptionVisible, put_IsCaptionVisible)
    IsContentVisible = property(get_IsContentVisible, put_IsContentVisible)
    IsGlyphVisible = property(get_IsGlyphVisible, put_IsGlyphVisible)
class DropOperationTargetRequestedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Input.DragDrop.IDropOperationTargetRequestedEventArgs
    _classid_ = 'Microsoft.UI.Input.DragDrop.DropOperationTargetRequestedEventArgs'
    @winrt_mixinmethod
    def SetTarget(self: win32more.Microsoft.UI.Input.DragDrop.IDropOperationTargetRequestedEventArgs, target: win32more.Microsoft.UI.Input.DragDrop.IDropOperationTarget) -> Void: ...
class IDragDropManager(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Input.DragDrop.IDragDropManager'
    _iid_ = Guid('{4fea9efc-b073-5fbe-9c95-a4113ef6393f}')
    @winrt_commethod(6)
    def get_AreConcurrentOperationsEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_AreConcurrentOperationsEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def add_TargetRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Input.DragDrop.DragDropManager, win32more.Microsoft.UI.Input.DragDrop.DropOperationTargetRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_TargetRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AreConcurrentOperationsEnabled = property(get_AreConcurrentOperationsEnabled, put_AreConcurrentOperationsEnabled)
    TargetRequested = event(add_TargetRequested, remove_TargetRequested)
class IDragDropManagerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Input.DragDrop.IDragDropManagerStatics'
    _iid_ = Guid('{5587c863-57d7-5d0f-8ea9-e5dcf06a0f83}')
    @winrt_commethod(6)
    def GetForIsland(self, content: win32more.Microsoft.UI.Content.ContentIsland) -> win32more.Microsoft.UI.Input.DragDrop.DragDropManager: ...
class IDragInfo(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Input.DragDrop.IDragInfo'
    _iid_ = Guid('{7507d891-62a8-5a79-a880-ac7353d001ec}')
    @winrt_commethod(6)
    def get_AllowedOperations(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation: ...
    @winrt_commethod(7)
    def get_Data(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageView: ...
    @winrt_commethod(8)
    def get_Modifiers(self) -> win32more.Microsoft.UI.Input.DragDrop.DragDropModifiers: ...
    @winrt_commethod(9)
    def get_Position(self) -> win32more.Windows.Foundation.Point: ...
    AllowedOperations = property(get_AllowedOperations, None)
    Data = property(get_Data, None)
    Modifiers = property(get_Modifiers, None)
    Position = property(get_Position, None)
class IDragOperation(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Input.DragDrop.IDragOperation'
    _iid_ = Guid('{ef122288-7984-53d3-8488-133dcd3de793}')
    @winrt_commethod(6)
    def get_AllowedOperations(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation: ...
    @winrt_commethod(7)
    def put_AllowedOperations(self, value: win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation) -> Void: ...
    @winrt_commethod(8)
    def get_Data(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackage: ...
    @winrt_commethod(9)
    def get_DragUIContentMode(self) -> win32more.Microsoft.UI.Input.DragDrop.DragUIContentMode: ...
    @winrt_commethod(10)
    def put_DragUIContentMode(self, value: win32more.Microsoft.UI.Input.DragDrop.DragUIContentMode) -> Void: ...
    @winrt_commethod(11)
    def SetDragUIContentFromSoftwareBitmap(self, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> Void: ...
    @winrt_commethod(12)
    def SetDragUIContentFromSoftwareBitmap2(self, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap, anchorPoint: win32more.Windows.Foundation.Point) -> Void: ...
    @winrt_commethod(13)
    def StartAsync(self, initialTarget: win32more.Microsoft.UI.Input.DragDrop.DragDropManager, initialPointerPoint: win32more.Microsoft.UI.Input.PointerPoint) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation]: ...
    AllowedOperations = property(get_AllowedOperations, put_AllowedOperations)
    Data = property(get_Data, None)
    DragUIContentMode = property(get_DragUIContentMode, put_DragUIContentMode)
class IDragUIOverride(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Input.DragDrop.IDragUIOverride'
    _iid_ = Guid('{8432fbac-a17f-5a95-8f56-fb432280b54d}')
    @winrt_commethod(6)
    def get_Caption(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Caption(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_IsCaptionVisible(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsCaptionVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_IsContentVisible(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsContentVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsGlyphVisible(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsGlyphVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def Clear(self) -> Void: ...
    @winrt_commethod(15)
    def SetContentFromSoftwareBitmap(self, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> Void: ...
    @winrt_commethod(16)
    def SetContentFromSoftwareBitmap2(self, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap, anchorPoint: win32more.Windows.Foundation.Point) -> Void: ...
    Caption = property(get_Caption, put_Caption)
    IsCaptionVisible = property(get_IsCaptionVisible, put_IsCaptionVisible)
    IsContentVisible = property(get_IsContentVisible, put_IsContentVisible)
    IsGlyphVisible = property(get_IsGlyphVisible, put_IsGlyphVisible)
class IDropOperationTarget(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Input.DragDrop.IDropOperationTarget'
    _iid_ = Guid('{1c2707d9-0065-53c7-bbfb-50850378caf3}')
    @winrt_commethod(6)
    def DropAsync(self, dragInfo: win32more.Microsoft.UI.Input.DragDrop.DragInfo) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation]: ...
    @winrt_commethod(7)
    def EnterAsync(self, dragInfo: win32more.Microsoft.UI.Input.DragDrop.DragInfo, dragUIOverride: win32more.Microsoft.UI.Input.DragDrop.DragUIOverride) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation]: ...
    @winrt_commethod(8)
    def LeaveAsync(self, dragInfo: win32more.Microsoft.UI.Input.DragDrop.DragInfo) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def OverAsync(self, dragInfo: win32more.Microsoft.UI.Input.DragDrop.DragInfo, dragUIOverride: win32more.Microsoft.UI.Input.DragDrop.DragUIOverride) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation]: ...
class IDropOperationTargetRequestedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Input.DragDrop.IDropOperationTargetRequestedEventArgs'
    _iid_ = Guid('{f61c5b62-720e-59ff-ad0b-e77fc5b8a4a3}')
    @winrt_commethod(6)
    def SetTarget(self, target: win32more.Microsoft.UI.Input.DragDrop.IDropOperationTarget) -> Void: ...


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.UI.Xaml
import win32more.Microsoft.UI.Xaml.Media.Media3D
class _CompositeTransform3D_Meta_(ComPtr.__class__):
    pass
class CompositeTransform3D(ComPtr, metaclass=_CompositeTransform3D_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Media.Media3D.Transform3D
    default_interface: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D
    _classid_ = 'Microsoft.UI.Xaml.Media.Media3D.CompositeTransform3D'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Media3D.CompositeTransform3D.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Media.Media3D.CompositeTransform3D: ...
    @winrt_mixinmethod
    def get_CenterX(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_CenterX(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_CenterY(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_CenterY(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_CenterZ(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_CenterZ(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_RotationX(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_RotationX(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_RotationY(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_RotationY(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_RotationZ(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_RotationZ(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ScaleX(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_ScaleX(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ScaleY(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_ScaleY(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ScaleZ(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_ScaleZ(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_TranslateX(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_TranslateX(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_TranslateY(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_TranslateY(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_TranslateZ(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_TranslateZ(self: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_classmethod
    def get_CenterXProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CenterYProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CenterZProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RotationXProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RotationYProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RotationZProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ScaleXProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ScaleYProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ScaleZProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TranslateXProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TranslateYProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TranslateZProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CenterX = property(get_CenterX, put_CenterX)
    CenterY = property(get_CenterY, put_CenterY)
    CenterZ = property(get_CenterZ, put_CenterZ)
    RotationX = property(get_RotationX, put_RotationX)
    RotationY = property(get_RotationY, put_RotationY)
    RotationZ = property(get_RotationZ, put_RotationZ)
    ScaleX = property(get_ScaleX, put_ScaleX)
    ScaleY = property(get_ScaleY, put_ScaleY)
    ScaleZ = property(get_ScaleZ, put_ScaleZ)
    TranslateX = property(get_TranslateX, put_TranslateX)
    TranslateY = property(get_TranslateY, put_TranslateY)
    TranslateZ = property(get_TranslateZ, put_TranslateZ)
    _CompositeTransform3D_Meta_.CenterXProperty = property(get_CenterXProperty, None)
    _CompositeTransform3D_Meta_.CenterYProperty = property(get_CenterYProperty, None)
    _CompositeTransform3D_Meta_.CenterZProperty = property(get_CenterZProperty, None)
    _CompositeTransform3D_Meta_.RotationXProperty = property(get_RotationXProperty, None)
    _CompositeTransform3D_Meta_.RotationYProperty = property(get_RotationYProperty, None)
    _CompositeTransform3D_Meta_.RotationZProperty = property(get_RotationZProperty, None)
    _CompositeTransform3D_Meta_.ScaleXProperty = property(get_ScaleXProperty, None)
    _CompositeTransform3D_Meta_.ScaleYProperty = property(get_ScaleYProperty, None)
    _CompositeTransform3D_Meta_.ScaleZProperty = property(get_ScaleZProperty, None)
    _CompositeTransform3D_Meta_.TranslateXProperty = property(get_TranslateXProperty, None)
    _CompositeTransform3D_Meta_.TranslateYProperty = property(get_TranslateYProperty, None)
    _CompositeTransform3D_Meta_.TranslateZProperty = property(get_TranslateZProperty, None)
class ICompositeTransform3D(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3D'
    _iid_ = Guid('{cbaf163f-c254-5dcf-8ae4-40e21ce1b4ca}')
    @winrt_commethod(6)
    def get_CenterX(self) -> Double: ...
    @winrt_commethod(7)
    def put_CenterX(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_CenterY(self) -> Double: ...
    @winrt_commethod(9)
    def put_CenterY(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_CenterZ(self) -> Double: ...
    @winrt_commethod(11)
    def put_CenterZ(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_RotationX(self) -> Double: ...
    @winrt_commethod(13)
    def put_RotationX(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_RotationY(self) -> Double: ...
    @winrt_commethod(15)
    def put_RotationY(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_RotationZ(self) -> Double: ...
    @winrt_commethod(17)
    def put_RotationZ(self, value: Double) -> Void: ...
    @winrt_commethod(18)
    def get_ScaleX(self) -> Double: ...
    @winrt_commethod(19)
    def put_ScaleX(self, value: Double) -> Void: ...
    @winrt_commethod(20)
    def get_ScaleY(self) -> Double: ...
    @winrt_commethod(21)
    def put_ScaleY(self, value: Double) -> Void: ...
    @winrt_commethod(22)
    def get_ScaleZ(self) -> Double: ...
    @winrt_commethod(23)
    def put_ScaleZ(self, value: Double) -> Void: ...
    @winrt_commethod(24)
    def get_TranslateX(self) -> Double: ...
    @winrt_commethod(25)
    def put_TranslateX(self, value: Double) -> Void: ...
    @winrt_commethod(26)
    def get_TranslateY(self) -> Double: ...
    @winrt_commethod(27)
    def put_TranslateY(self, value: Double) -> Void: ...
    @winrt_commethod(28)
    def get_TranslateZ(self) -> Double: ...
    @winrt_commethod(29)
    def put_TranslateZ(self, value: Double) -> Void: ...
    CenterX = property(get_CenterX, put_CenterX)
    CenterY = property(get_CenterY, put_CenterY)
    CenterZ = property(get_CenterZ, put_CenterZ)
    RotationX = property(get_RotationX, put_RotationX)
    RotationY = property(get_RotationY, put_RotationY)
    RotationZ = property(get_RotationZ, put_RotationZ)
    ScaleX = property(get_ScaleX, put_ScaleX)
    ScaleY = property(get_ScaleY, put_ScaleY)
    ScaleZ = property(get_ScaleZ, put_ScaleZ)
    TranslateX = property(get_TranslateX, put_TranslateX)
    TranslateY = property(get_TranslateY, put_TranslateY)
    TranslateZ = property(get_TranslateZ, put_TranslateZ)
class ICompositeTransform3DStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics'
    _iid_ = Guid('{b64d4181-6988-5d46-858a-224db7089dc4}')
    @winrt_commethod(6)
    def get_CenterXProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CenterYProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CenterZProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_RotationXProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_RotationYProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_RotationZProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ScaleXProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_ScaleYProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_ScaleZProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_TranslateXProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_TranslateYProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_TranslateZProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CenterXProperty = property(get_CenterXProperty, None)
    CenterYProperty = property(get_CenterYProperty, None)
    CenterZProperty = property(get_CenterZProperty, None)
    RotationXProperty = property(get_RotationXProperty, None)
    RotationYProperty = property(get_RotationYProperty, None)
    RotationZProperty = property(get_RotationZProperty, None)
    ScaleXProperty = property(get_ScaleXProperty, None)
    ScaleYProperty = property(get_ScaleYProperty, None)
    ScaleZProperty = property(get_ScaleZProperty, None)
    TranslateXProperty = property(get_TranslateXProperty, None)
    TranslateYProperty = property(get_TranslateYProperty, None)
    TranslateZProperty = property(get_TranslateZProperty, None)
class IMatrix3DHelper(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Media3D.IMatrix3DHelper'
    _iid_ = Guid('{d2909be1-9c28-5b38-b63c-88e838644533}')
class IMatrix3DHelperStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Media3D.IMatrix3DHelperStatics'
    _iid_ = Guid('{930e447b-265c-5ded-9e64-57b8933c55c3}')
    @winrt_commethod(6)
    def get_Identity(self) -> win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D: ...
    @winrt_commethod(7)
    def Multiply(self, matrix1: win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D, matrix2: win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D) -> win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D: ...
    @winrt_commethod(8)
    def FromElements(self, m11: Double, m12: Double, m13: Double, m14: Double, m21: Double, m22: Double, m23: Double, m24: Double, m31: Double, m32: Double, m33: Double, m34: Double, offsetX: Double, offsetY: Double, offsetZ: Double, m44: Double) -> win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D: ...
    @winrt_commethod(9)
    def GetHasInverse(self, target: win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D) -> Boolean: ...
    @winrt_commethod(10)
    def GetIsIdentity(self, target: win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D) -> Boolean: ...
    @winrt_commethod(11)
    def Invert(self, target: win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D) -> win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D: ...
    Identity = property(get_Identity, None)
class IPerspectiveTransform3D(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Media3D.IPerspectiveTransform3D'
    _iid_ = Guid('{4006cc46-684e-54ea-a421-dae5b0556b85}')
    @winrt_commethod(6)
    def get_Depth(self) -> Double: ...
    @winrt_commethod(7)
    def put_Depth(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_OffsetX(self) -> Double: ...
    @winrt_commethod(9)
    def put_OffsetX(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_OffsetY(self) -> Double: ...
    @winrt_commethod(11)
    def put_OffsetY(self, value: Double) -> Void: ...
    Depth = property(get_Depth, put_Depth)
    OffsetX = property(get_OffsetX, put_OffsetX)
    OffsetY = property(get_OffsetY, put_OffsetY)
class IPerspectiveTransform3DStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Media3D.IPerspectiveTransform3DStatics'
    _iid_ = Guid('{3b16aa8d-0ee2-5d46-a723-dc8e5c1c0b19}')
    @winrt_commethod(6)
    def get_DepthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OffsetXProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_OffsetYProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DepthProperty = property(get_DepthProperty, None)
    OffsetXProperty = property(get_OffsetXProperty, None)
    OffsetYProperty = property(get_OffsetYProperty, None)
class ITransform3D(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Media3D.ITransform3D'
    _iid_ = Guid('{afea4941-2e49-533c-9f8f-2c126ef9893a}')
class ITransform3DFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Media3D.ITransform3DFactory'
    _iid_ = Guid('{9bcce0a1-10ac-5319-bdf1-548d2e5ae504}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Media.Media3D.Transform3D: ...
class Matrix3D(Structure):
    _name_ = 'Microsoft.UI.Xaml.Media.Media3D.Matrix3D'
    M11: Double
    M12: Double
    M13: Double
    M14: Double
    M21: Double
    M22: Double
    M23: Double
    M24: Double
    M31: Double
    M32: Double
    M33: Double
    M34: Double
    OffsetX: Double
    OffsetY: Double
    OffsetZ: Double
    M44: Double
class _Matrix3DHelper_Meta_(ComPtr.__class__):
    pass
class Matrix3DHelper(ComPtr, metaclass=_Matrix3DHelper_Meta_):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Media.Media3D.IMatrix3DHelper
    _classid_ = 'Microsoft.UI.Xaml.Media.Media3D.Matrix3DHelper'
    @winrt_classmethod
    def get_Identity(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.IMatrix3DHelperStatics) -> win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D: ...
    @winrt_classmethod
    def Multiply(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.IMatrix3DHelperStatics, matrix1: win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D, matrix2: win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D) -> win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D: ...
    @winrt_classmethod
    def FromElements(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.IMatrix3DHelperStatics, m11: Double, m12: Double, m13: Double, m14: Double, m21: Double, m22: Double, m23: Double, m24: Double, m31: Double, m32: Double, m33: Double, m34: Double, offsetX: Double, offsetY: Double, offsetZ: Double, m44: Double) -> win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D: ...
    @winrt_classmethod
    def GetHasInverse(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.IMatrix3DHelperStatics, target: win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D) -> Boolean: ...
    @winrt_classmethod
    def GetIsIdentity(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.IMatrix3DHelperStatics, target: win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D) -> Boolean: ...
    @winrt_classmethod
    def Invert(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.IMatrix3DHelperStatics, target: win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D) -> win32more.Microsoft.UI.Xaml.Media.Media3D.Matrix3D: ...
    _Matrix3DHelper_Meta_.Identity = property(get_Identity, None)
class _PerspectiveTransform3D_Meta_(ComPtr.__class__):
    pass
class PerspectiveTransform3D(ComPtr, metaclass=_PerspectiveTransform3D_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Media.Media3D.Transform3D
    default_interface: win32more.Microsoft.UI.Xaml.Media.Media3D.IPerspectiveTransform3D
    _classid_ = 'Microsoft.UI.Xaml.Media.Media3D.PerspectiveTransform3D'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Media3D.PerspectiveTransform3D.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Media.Media3D.PerspectiveTransform3D: ...
    @winrt_mixinmethod
    def get_Depth(self: win32more.Microsoft.UI.Xaml.Media.Media3D.IPerspectiveTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_Depth(self: win32more.Microsoft.UI.Xaml.Media.Media3D.IPerspectiveTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_OffsetX(self: win32more.Microsoft.UI.Xaml.Media.Media3D.IPerspectiveTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_OffsetX(self: win32more.Microsoft.UI.Xaml.Media.Media3D.IPerspectiveTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_OffsetY(self: win32more.Microsoft.UI.Xaml.Media.Media3D.IPerspectiveTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_OffsetY(self: win32more.Microsoft.UI.Xaml.Media.Media3D.IPerspectiveTransform3D, value: Double) -> Void: ...
    @winrt_classmethod
    def get_DepthProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.IPerspectiveTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OffsetXProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.IPerspectiveTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OffsetYProperty(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.IPerspectiveTransform3DStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Depth = property(get_Depth, put_Depth)
    OffsetX = property(get_OffsetX, put_OffsetX)
    OffsetY = property(get_OffsetY, put_OffsetY)
    _PerspectiveTransform3D_Meta_.DepthProperty = property(get_DepthProperty, None)
    _PerspectiveTransform3D_Meta_.OffsetXProperty = property(get_OffsetXProperty, None)
    _PerspectiveTransform3D_Meta_.OffsetYProperty = property(get_OffsetYProperty, None)
class Transform3D(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Media.Media3D.ITransform3D
    _classid_ = 'Microsoft.UI.Xaml.Media.Media3D.Transform3D'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Media3D.Transform3D.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Media.Media3D.ITransform3DFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Media.Media3D.Transform3D: ...


make_ready(__name__)
